Assert that required Gazepoint columns are present
Source:R/roadmap-remaining-helpers.R
assert_gazepoint_columns.RdValidates expected columns and either throws an error, raises a warning, or returns a summary table.

R/roadmap-remaining-helpers.R
assert_gazepoint_columns.RdValidates expected columns and either throws an error, raises a warning, or returns a summary table.