Skip to contents

Launches an optional local Shiny interface for inspecting a Gazepoint Biometrics CSV file. Shiny is optional and is not required to use the package.

Usage

run_gpbiometrics_shiny()

Value

A Shiny application object, launched for interactive use.