Create a gpbiometrics feature inventory
Source:R/feature-inventory.R
create_gazepoint_biometrics_feature_inventory.RdCreates a structured inventory of implemented gpbiometrics helper functions. This is useful for reporting, readiness checks, documentation, and package development audits.