Create a gpbiometrics release checklist
Source:R/release-readiness-audit.R
create_gazepoint_release_checklist.RdCreates a conservative release checklist. If an audit table is supplied, each checklist item is linked to the current audit status. The checklist is meant to support human review before tagging or submission.