Standardize Gazepoint plot return contracts
Source:R/compatibility-aliases.R
standardize_gazepoint_plot_contracts.RdUS-spelling compatibility wrapper around
standardise_gazepoint_plot_contract(). The wrapper accepts either a single
ggplot object or a list of ggplot objects. For a list of plots, plot_data,
settings, interpretation_notes, and plot_type may be supplied either as
single values applied to all plots or as same-length lists/vectors applied
elementwise.
Usage
standardize_gazepoint_plot_contracts(
plot,
plot_data = NULL,
settings = list(),
interpretation_notes = NULL,
plot_type = NULL
)Arguments
- plot
A ggplot object, or a list of ggplot objects.
- plot_data
Optional data frame, or a list of data frames when
plotis a list.- settings
Optional settings list, or a list of settings lists when
plotis a list.- interpretation_notes
Optional character vector, or a list/character vector of notes when
plotis a list.- plot_type
Optional plot-type label, or a character vector/list of labels when
plotis a list.